==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/TimeStopClock.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.server.DelayedTask;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_8915;
import net.minecraft.server.MinecraftServer;

public class TimeStopClock extends class_1792 {
    public TimeStopClock(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        MinecraftServer server = world.method_8503();
        if (!world.field_9236 && server != null) {
            class_1799 itemStack = user.method_5998(hand);
            class_8915 tickManager = server.method_54833();
            boolean freeze = tickManager.method_54754();
            if (!freeze) {
                world.method_8396(null, user.method_24515(), class_3417.field_15119, class_3419.field_15245, 0.5f, 1);
            } else {
                world.method_8396(null, user.method_24515(), class_3417.field_14785, class_3419.field_15245, 0.5f, 1);
            }
            tickManager.method_54675(!freeze);
            if (!user.method_56992()) {
                itemStack.method_61653(1, user);
                if (itemStack.method_7963() && itemStack.method_7919() >= itemStack.method_7936()) {
                    itemStack.method_7934(1);
                }
            }
            DelayedTask.create(server, 20 * 20, () -> {
                if (tickManager.method_54754()) {
                    tickManager.method_54675(false);
                }
            });
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/TimeStopClock.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.server.DelayedTask;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1796;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_8915;
import net.minecraft.server.MinecraftServer;

public class TimeStopClock extends class_1792 {
    public static DelayedTask TASK = null;

    public TimeStopClock(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        MinecraftServer server = world.method_8503();
        if (!world.field_9236 && server != null) {
            class_1799 itemStack = user.method_5998(hand);
            class_1796 itemCooldownManager = user.method_7357();
            itemCooldownManager.method_62835(itemStack, 20 * 10);
            class_8915 tickManager = server.method_54833();
            boolean freeze = tickManager.method_54754();
            if (!freeze) {
                world.method_8396(null, user.method_24515(), class_3417.field_15119, class_3419.field_15245, 0.5f, 1);
            } else {
                world.method_8396(null, user.method_24515(), class_3417.field_14785, class_3419.field_15245, 0.5f, 1);
            }
            tickManager.method_54675(!freeze);
            if (!user.method_56992()) {
                itemStack.method_61653(1, user);
                if (itemStack.method_7963() && itemStack.method_7919() >= itemStack.method_7936()) {
                    itemStack.method_7934(1);
                }
            }
            if (TASK != null) {
                TASK.stop();
            }
            TASK = DelayedTask.create(server, 20 * 20, () -> {
                if (tickManager.method_54754()) {
                    tickManager.method_54675(false);
                }
                TASK = null;
            });
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}
